==> openshift-model-console-5.9.0-sources.jar: io/fabric8/openshift/api/model/console/v1/NamespaceDashboardSpecFluent.java <==
package io.fabric8.openshift.api.model.console.v1;

import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.model.LabelSelector;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import io.fabric8.kubernetes.api.model.LabelSelectorFluent;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface NamespaceDashboardSpecFluent<A extends io.fabric8.openshift.api.model.console.v1.NamespaceDashboardSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildNamespaceSelector instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.LabelSelector getNamespaceSelector();
  public io.fabric8.kubernetes.api.model.LabelSelector buildNamespaceSelector();
  public A withNamespaceSelector(io.fabric8.kubernetes.api.model.LabelSelector namespaceSelector);
  public java.lang.Boolean hasNamespaceSelector();
  public io.fabric8.openshift.api.model.console.v1.NamespaceDashboardSpecFluent.NamespaceSelectorNested<A> withNewNamespaceSelector();
  public io.fabric8.openshift.api.model.console.v1.NamespaceDashboardSpecFluent.NamespaceSelectorNested<A> withNewNamespaceSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item);
  public io.fabric8.openshift.api.model.console.v1.NamespaceDashboardSpecFluent.NamespaceSelectorNested<A> editNamespaceSelector();
  public io.fabric8.openshift.api.model.console.v1.NamespaceDashboardSpecFluent.NamespaceSelectorNested<A> editOrNewNamespaceSelector();
  public io.fabric8.openshift.api.model.console.v1.NamespaceDashboardSpecFluent.NamespaceSelectorNested<A> editOrNewNamespaceSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item);
  public A addToNamespaces(java.lang.Integer index,java.lang.String item);
  public A setToNamespaces(java.lang.Integer index,java.lang.String item);
  public A addToNamespaces(java.lang.String... items);
  public A addAllToNamespaces(java.util.Collection<java.lang.String> items);
  public A removeFromNamespaces(java.lang.String... items);
  public A removeAllFromNamespaces(java.util.Collection<java.lang.String> items);
  public java.util.List<java.lang.String> getNamespaces();
  public java.lang.String getNamespace(java.lang.Integer index);
  public java.lang.String getFirstNamespace();
  public java.lang.String getLastNamespace();
  public java.lang.String getMatchingNamespace(java.util.function.Predicate<java.lang.String> predicate);
  public java.lang.Boolean hasMatchingNamespace(java.util.function.Predicate<java.lang.String> predicate);
  public A withNamespaces(java.util.List<java.lang.String> namespaces);
  public A withNamespaces(java.lang.String... namespaces);
  public java.lang.Boolean hasNamespaces();
  public A addNewNamespace(java.lang.String arg0);
  public interface NamespaceSelectorNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.LabelSelectorFluent<io.fabric8.openshift.api.model.console.v1.NamespaceDashboardSpecFluent.NamespaceSelectorNested<N>>{
    public N and();
    public N endNamespaceSelector();
    
  }
  
}

==> openshift-model-console-5.12.2-sources.jar: io/fabric8/openshift/api/model/console/v1/NamespaceDashboardSpecFluent.java <==
package io.fabric8.openshift.api.model.console.v1;

import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.model.LabelSelector;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import io.fabric8.kubernetes.api.model.LabelSelectorFluent;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface NamespaceDashboardSpecFluent<A extends io.fabric8.openshift.api.model.console.v1.NamespaceDashboardSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildNamespaceSelector instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.LabelSelector getNamespaceSelector();
  public io.fabric8.kubernetes.api.model.LabelSelector buildNamespaceSelector();
  public A withNamespaceSelector(io.fabric8.kubernetes.api.model.LabelSelector namespaceSelector);
  public java.lang.Boolean hasNamespaceSelector();
  public io.fabric8.openshift.api.model.console.v1.NamespaceDashboardSpecFluent.NamespaceSelectorNested<A> withNewNamespaceSelector();
  public io.fabric8.openshift.api.model.console.v1.NamespaceDashboardSpecFluent.NamespaceSelectorNested<A> withNewNamespaceSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item);
  public io.fabric8.openshift.api.model.console.v1.NamespaceDashboardSpecFluent.NamespaceSelectorNested<A> editNamespaceSelector();
  public io.fabric8.openshift.api.model.console.v1.NamespaceDashboardSpecFluent.NamespaceSelectorNested<A> editOrNewNamespaceSelector();
  public io.fabric8.openshift.api.model.console.v1.NamespaceDashboardSpecFluent.NamespaceSelectorNested<A> editOrNewNamespaceSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item);
  public A addToNamespaces(java.lang.Integer index,java.lang.String item);
  public A setToNamespaces(java.lang.Integer index,java.lang.String item);
  public A addToNamespaces(java.lang.String... items);
  public A addAllToNamespaces(java.util.Collection<java.lang.String> items);
  public A removeFromNamespaces(java.lang.String... items);
  public A removeAllFromNamespaces(java.util.Collection<java.lang.String> items);
  public java.util.List<java.lang.String> getNamespaces();
  public java.lang.String getNamespace(java.lang.Integer index);
  public java.lang.String getFirstNamespace();
  public java.lang.String getLastNamespace();
  public java.lang.String getMatchingNamespace(java.util.function.Predicate<java.lang.String> predicate);
  public java.lang.Boolean hasMatchingNamespace(java.util.function.Predicate<java.lang.String> predicate);
  public A withNamespaces(java.util.List<java.lang.String> namespaces);
  public A withNamespaces(java.lang.String... namespaces);
  public java.lang.Boolean hasNamespaces();
  public A addNewNamespace(java.lang.String arg0);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface NamespaceSelectorNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.LabelSelectorFluent<io.fabric8.openshift.api.model.console.v1.NamespaceDashboardSpecFluent.NamespaceSelectorNested<N>>{
    public N and();
    public N endNamespaceSelector();
    
  }
  
}
